.. cognite-sdk documentation master file, created by
   sphinx-quickstart on Thu Jan 11 15:57:44 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cognite Python SDK Documentation
================================

This is the Cognite Python SDK for developers and data scientists working with Cognite Data Fusion (CDF). The package is tightly integrated with pandas, and helps you work easily and efficiently with data in Cognite Data Fusion (CDF). 

.. contents::
   :local:

Installation
^^^^^^^^^^^^
To install this package:

.. code-block:: bash

   pip install cognite-sdk

To upgrade the version of this package:

.. code-block:: bash

   pip install cognite-sdk --upgrade

To install this package without the pandas and NumPy support:

.. code-block:: bash

   pip install cognite-sdk-core

Contents
^^^^^^^^
.. toctree::
   cognite

Examples
^^^^^^^^
For a collection of scripts and Jupyter Notebooks that explain how to perform various tasks in Cognite Data Fusion (CDF) using Python, see the GitHub repository `here <https://github.com/  cognitedata/cognite-python-docs>`__.
